==========================
How to contribute to Solum
==========================

If you would like to contribute to Solum, please see our contributing wiki:
   https://wiki.openstack.org/wiki/Solum/Contributing

We have the same CLA requirements as OpenStack, so you must follow the steps 
in the "If you're a developer, start here" section of this page:

   https://docs.openstack.org/infra/manual/developers.html

Once those steps have been completed, submit your changes to for review via 
the Gerrit tool, following the workflow documented at:

   https://docs.openstack.org/infra/manual/developers.html#development-workflow

Pull requests submitted through GitHub will be ignored.

Bugs should be filed on Launchpad, not GitHub:

   https://bugs.launchpad.net/solum

For tips to help with running unit tests and functional tests on your code,
see:

   https://wiki.openstack.org/wiki/Solum/Testing
